@@ -37,20 +37,20 @@ WifiSecurity::WifiSecurity(const NetworkManager::Setting::Ptr &setting, const Ne
     m_ui->stackedWidget->insertWidget(3, m_8021xWidget);
     m_ui->stackedWidget->insertWidget(5, m_WPA2Widget);
 
-    connect(m_ui->securityCombo, SIGNAL(currentIndexChanged(int)), SLOT(securityChanged(int)));
+    connect(m_ui->securityCombo, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &WifiSecurity::securityChanged);
 
-    connect(m_ui->cbShowWepKey, SIGNAL(toggled(bool)), SLOT(slotShowWepKeyPasswordChecked(bool)));
-    connect(m_ui->cbShowLeapPassword, SIGNAL(toggled(bool)), SLOT(slotShowLeapPasswordChecked(bool)));
-    connect(m_ui->cbShowPsk, SIGNAL(toggled(bool)), SLOT(slotShowPskPasswordChecked(bool)));
+    connect(m_ui->cbShowWepKey, &QCheckBox::toggled, this, &WifiSecurity::slotShowWepKeyPasswordChecked);
+    connect(m_ui->cbShowLeapPassword, &QCheckBox::toggled, this, &WifiSecurity::slotShowLeapPasswordChecked);
+    connect(m_ui->cbShowPsk, &QCheckBox::toggled, this, &WifiSecurity::slotShowPskPasswordChecked);
 
-    connect(m_ui->wepIndex, SIGNAL(currentIndexChanged(int)), SLOT(setWepKey(int)));
+    connect(m_ui->wepIndex, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &WifiSecurity::setWepKey);
 
-    connect(m_ui->wepKey, SIGNAL(textChanged(QString)), SLOT(slotWidgetChanged()));
-    connect(m_ui->leapUsername, SIGNAL(textChanged(QString)), SLOT(slotWidgetChanged()));
-    connect(m_ui->leapPassword, SIGNAL(textChanged(QString)), SLOT(slotWidgetChanged()));
-    connect(m_ui->psk, SIGNAL(textChanged(QString)), SLOT(slotWidgetChanged()));
-    connect(m_ui->wepIndex, SIGNAL(currentIndexChanged(int)), SLOT(slotWidgetChanged()));
-    connect(m_ui->securityCombo, SIGNAL(currentIndexChanged(int)), SLOT(slotWidgetChanged()));
+    connect(m_ui->wepKey, &KLineEdit::textChanged, this, &WifiSecurity::slotWidgetChanged);
+    connect(m_ui->leapUsername, &KLineEdit::textChanged, this, &WifiSecurity::slotWidgetChanged);
+    connect(m_ui->leapPassword, &KLineEdit::textChanged, this, &WifiSecurity::slotWidgetChanged);
+    connect(m_ui->psk, &KLineEdit::textChanged, this, &WifiSecurity::slotWidgetChanged);
+    connect(m_ui->wepIndex, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &WifiSecurity::slotWidgetChanged);
+    connect(m_ui->securityCombo, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &WifiSecurity::slotWidgetChanged);
 
     KAcceleratorManager::manage(this);
 
@@ -112,7 +112,6 @@ void WifiSecurity::loadConfig(const NetworkManager::Setting::Ptr &setting)
             m_ui->securityCombo->setCurrentIndex(WepPassphrase);
         }
         const int keyIndex = static_cast<int>(wifiSecurity->wepTxKeyindex());
-        setWepKey(keyIndex);
         m_ui->wepIndex->setCurrentIndex(keyIndex);
 
         if (wifiSecurity->authAlg() == NetworkManager::WirelessSecuritySetting::Open) {
@@ -134,12 +133,54 @@ void WifiSecurity::loadConfig(const NetworkManager::Setting::Ptr &setting)
 
     } else if (keyMgmt == NetworkManager::WirelessSecuritySetting::WpaPsk) {
         m_ui->securityCombo->setCurrentIndex(WpaPsk);  // WPA
-        m_ui->psk->setText(wifiSecurity->psk());
 
     } else if (keyMgmt == NetworkManager::WirelessSecuritySetting::WpaEap) {
         m_ui->securityCombo->setCurrentIndex(WpaEap);  // WPA2 Enterprise
         // done in the widget
     }
+
+    if (keyMgmt != NetworkManager::WirelessSecuritySetting::Ieee8021x &&
+        keyMgmt != NetworkManager::WirelessSecuritySetting::WpaEap) {
+        loadSecrets(setting);
+    }
+}
+
+void WifiSecurity::loadSecrets(const NetworkManager::Setting::Ptr &setting)
+{
+    const NetworkManager::WirelessSecuritySetting::KeyMgmt keyMgmt = m_wifiSecurity->keyMgmt();
+    const NetworkManager::WirelessSecuritySetting::AuthAlg authAlg = m_wifiSecurity->authAlg();
+
+    if (keyMgmt == NetworkManager::WirelessSecuritySetting::Ieee8021x ||
+        keyMgmt == NetworkManager::WirelessSecuritySetting::WpaEap) {
+        NetworkManager::Security8021xSetting::Ptr security8021xSetting = setting.staticCast<NetworkManager::Security8021xSetting>();
+        if (security8021xSetting) {
+            if (keyMgmt == NetworkManager::WirelessSecuritySetting::Ieee8021x) {
+                m_8021xWidget->loadSecrets(security8021xSetting);
+            } else {
+                m_WPA2Widget->loadSecrets(security8021xSetting);
+            }
+        }
+    } else {
+        NetworkManager::WirelessSecuritySetting::Ptr wifiSecurity = setting.staticCast<NetworkManager::WirelessSecuritySetting>();
+        if (wifiSecurity) {
+            if (keyMgmt == NetworkManager::WirelessSecuritySetting::Wep) {
+                m_wifiSecurity->secretsFromMap(wifiSecurity->secretsToMap());
+                const int keyIndex = static_cast<int>(m_wifiSecurity->wepTxKeyindex());
+                setWepKey(keyIndex);
+            } else if (keyMgmt == NetworkManager::WirelessSecuritySetting::Ieee8021x
+                    && authAlg == NetworkManager::WirelessSecuritySetting::Leap) {
+                const QString leapPassword = wifiSecurity->leapPassword();
+                if (!leapPassword.isEmpty()) {
+                    m_ui->leapPassword->setText(leapPassword);
+                }
+            } else if (keyMgmt == NetworkManager::WirelessSecuritySetting::WpaPsk) {
+                const QString psk = wifiSecurity->psk();
+                if (!psk.isEmpty()) {
+                    m_ui->psk->setText(psk);
+                }
+            }
+        }
+    }
 }
 
 QVariantMap WifiSecurity::setting(bool agentOwned) const
