@@ -32,12 +32,13 @@ public:
 };
 
 OpenswanAuthDialog::OpenswanAuthDialog(const NetworkManager::VpnSetting::Ptr &setting, QWidget * parent)
-    : SettingWidget(setting, parent), d_ptr(new OpenswanAuthDialogPrivate)
+    : SettingWidget(setting, parent)
+    , d_ptr(new OpenswanAuthDialogPrivate)
 {
     Q_D(OpenswanAuthDialog);
     d->ui.setupUi(this);
     d->setting = setting;
-    connect(d->ui.cbShowPasswords, SIGNAL(toggled(bool)), this, SLOT(showPasswordsChanged(bool)));
+    connect(d->ui.cbShowPasswords, &QCheckBox::toggled, this, &OpenswanAuthDialog::showPasswordsChanged);
 
     readSecrets();
 
