@@ -39,7 +39,8 @@ public:
 };
 
 OpenVpnAuthWidget::OpenVpnAuthWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget * parent)
-    : SettingWidget(setting, parent), d_ptr(new OpenVpnAuthWidgetPrivate)
+    : SettingWidget(setting, parent)
+    , d_ptr(new OpenVpnAuthWidgetPrivate)
 {
     Q_D(OpenVpnAuthWidget);
     d->setting = setting;
@@ -127,7 +128,7 @@ void OpenVpnAuthWidget::readSecrets()
     QCheckBox *showPasswords = new QCheckBox(this);
     showPasswords->setText(i18n("Show passwords"));
     d->layout->addRow(showPasswords);
-    connect(showPasswords, SIGNAL(toggled(bool)), this, SLOT(showPasswordsToggled(bool)));
+    connect(showPasswords, &QCheckBox::toggled, this, &OpenVpnAuthWidget::showPasswordsToggled);
 }
 
 QVariantMap OpenVpnAuthWidget::setting(bool agentOwned) const
@@ -155,10 +156,11 @@ void OpenVpnAuthWidget::showPasswordsToggled(bool show)
     for (int i = 0; i < d->layout->rowCount() - 1; i++) {
         QLineEdit *le = qobject_cast<QLineEdit*>(d->layout->itemAt(i, QFormLayout::FieldRole)->widget());
         if (le) {
-            if (show)
+            if (show) {
                 le->setEchoMode(QLineEdit::Normal);
-            else
+            } else {
                 le->setEchoMode(QLineEdit::Password);
+            }
         }
     }
 }
